.. pycounter documentation master file, created by
   sphinx-quickstart on Thu Nov 13 08:44:21 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pycounter
=========

Release v\ |version|

.. include:: ../../README.rst
   :start-line: 18

API Docs
========

.. autosummary::

   pycounter.report
   pycounter.sushi


Indices and tables
==================


* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Contents
========

.. toctree::

    pycounter
    sushiclient
